@@ -32,14 +32,19 @@
 #include <osmocom/gsm/gsm_utils.h>
 #include <osmocom/gsm/protocol/gsm_04_08.h>
 #include <osmocom/gsm/rsl.h>
+#include <osmocom/gsm/tlv.h>
+#include <osmocom/gsm/lapdm.h>
 
 #include <osmocom/bb/common/l1ctl.h>
 #include <osmocom/bb/common/osmocom_data.h>
+#include <osmocom/bb/common/ms.h>
 #include <osmocom/bb/common/logging.h>
 #include <osmocom/bb/common/networks.h>
 #include <osmocom/bb/common/gps.h>
+#include <osmocom/bb/common/sysinfo.h>
+#include <osmocom/bb/mobile/gsm48_rr.h>
 #include <osmocom/bb/misc/cell_log.h>
-#include "../../../gsmmap/geo.h"
+#include <osmocom/bb/misc/geo.h>
 
 #define READ_WAIT	2, 0
 #define RACH_WAIT	0, 900000
@@ -93,7 +98,7 @@ static struct log_si {
 	uint16_t flags;
 	uint8_t bsic;
 	int8_t rxlev_dbm;
-	uint16_t mcc, mnc, lac, cellid;
+	struct osmo_cell_global_id cgi;
 	uint8_t ta;
 	double latitude, longitude;
 } log_si;
@@ -182,9 +187,10 @@ static void log_sysinfo(void)
 	if (log_si.ta != 0xff)
 		sprintf(ta_str, " TA=%d", log_si.ta);
 
-	LOGP(DSUM, LOGL_INFO, "Cell: ARFCN=%d MCC=%s MNC=%s (%s, %s)%s\n",
-		arfcn, gsm_print_mcc(s->mcc), gsm_print_mnc(s->mnc),
-		gsm_get_mcc(s->mcc), gsm_get_mnc(s->mcc, s->mnc), ta_str);
+	LOGP(DSUM, LOGL_INFO, "Cell: ARFCN=%d MCC-MNC=%s (%s, %s)%s\n",
+		arfcn, osmo_plmn_name(&s->lai.plmn),
+		gsm_get_mcc(s->lai.plmn.mcc),
+		gsm_get_mnc(&s->lai.plmn), ta_str);
 
 	LOGFILE("[sysinfo]\n");
 	LOGFILE("arfcn %d\n", s->arfcn);
@@ -287,7 +293,7 @@ static void start_rach(void)
 	ncch->data[2] = (s->ccch_conf == 1) << 7;
 	ncch->data[3] = 0;
 	ncch->data[4] = RSL_IE_ACCESS_DELAY;
-	ncch->data[5] = 0; /* no delay */ 
+	ncch->data[5] = 0; /* no delay */
 	ncch->data[6] = RSL_IE_MS_POWER;
 	ncch->data[7] = 0; /* full power */
 
@@ -665,7 +671,7 @@ static int unit_data_ind(struct osmocom_ms *ms, struct msgb *msg)
 	struct abis_rsl_rll_hdr *rllh = msgb_l2(msg);
 	struct tlv_parsed tv;
 	uint8_t ch_type, ch_subch, ch_ts;
-	
+
 	DEBUGP(DRSL, "RSLms UNIT DATA IND chan_nr=0x%02x link_id=0x%02x\n",
 		rllh->chan_nr, rllh->link_id);
 
